@@ -1,5 +1,12 @@
 """
 Import tiddlers, Cook recipes, TiddlyWikis into TiddlyWeb.
+
+If you wish to use the provided "twimport" twanager command
+you must add to twanager_plugins in tiddlywebconfig.py:
+
+    config = {
+        'twanager_plugins': ['tiddlywebplugins.twimport'],
+    }
 """
 
 import os
@@ -57,7 +64,7 @@ def import_one(bag_name, url, store):
                 tiddler_url in recipe_to_urls(url)]
     elif url.endswith('.wiki') or url.endswith('.html'):
         tiddlers = wiki_to_tiddlers(url)
-    else: # we have a tiddler of some form
+    else:  # we have a tiddler of some form
         tiddlers = [url_to_tiddler(url)]
 
     for tiddler in tiddlers:
@@ -245,7 +252,7 @@ def _expand_recipe(content, url=''):
         try:
             target_type, target = line.split(':', 1)
         except ValueError:
-            continue # blank line in recipe
+            continue  # blank line in recipe
         if target_type in ACCEPTED_RECIPE_TYPES:
             if isinstance(target, unicode):
                 target = target.encode('utf-8')
@@ -268,7 +275,6 @@ def _expand_recipe(content, url=''):
     return urls
 
 
-
 def _get_url(url):
     """
     Load a URL and decode it to unicode.
@@ -320,7 +326,7 @@ def _get_tiddler_from_div(node):
                 tiddler.fields[attr] = data
     if not node.attributes.get('modified', None) and tiddler.created:
         tiddler.modified = tiddler.created
-    tiddler.tags = string_to_tags_list(str(node.getAttribute('tags')))
+    tiddler.tags = string_to_tags_list(node.getAttribute('tags'))
 
     return tiddler
 
@@ -335,9 +341,11 @@ def get_url_handle(url):
             try:
                 handle = urllib2.urlopen(url)
             except (urllib2.URLError, OSError):
-                scheme, netloc, path, params, query, fragment = urlparse.urlparse(url)
+                (scheme, netloc, path, params, query,
+                        fragment) = urlparse.urlparse(url)
                 path = urllib.quote(path)
-                newurl = urlparse.urlunparse((scheme, netloc, path, params, query, fragment))
+                newurl = urlparse.urlunparse((scheme, netloc, path,
+                    params, query, fragment))
                 handle = urllib2.urlopen(newurl)
         except ValueError:
             # If ValueError happens again we want it to raise
@@ -348,7 +356,6 @@ def get_url_handle(url):
         raise ValueError('%s: %s' % (exc, url))
 
 
-
 def _html_decode(text):
     """
     Decode HTML entities used in TiddlyWiki content into the 'real' things.
